==> ejc-bfyjerp-api-3.0.0-20250121.091119-117-sources.jar: com/ejianc/business/oa/vo/InsurancePaymentSetVO.java <==
package com.ejianc.business.oa.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 人力申请-保险缴纳申请基数设置
 * 
 * @author generator
 * 
 */
public class InsurancePaymentSetVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String createUserName; // 创建人名称
    private String modifyUserName; // 修改人名称
    private BigDecimal insurancePaymentBaseMny; // 保险缴纳基数
    private BigDecimal undertakePercent; // 费用承担比例
    private BigDecimal endownmentPersonPercent; // 养老保险个人比例
    private BigDecimal endownmentCompanyPercent; // 养老保险企业比例
    private BigDecimal unemployeePersonPercent; // 失业保险个人比例
    private BigDecimal unemployeeCompanyPercent; // 失业保险企业比例
    private BigDecimal injuryPersonPercent; // 工伤保险个人比例
    private BigDecimal injuryCompanyPercent; // 工伤保险企业比例
    private BigDecimal baseMedicalPersonPercent; // 基本医疗保险个人比例
    private BigDecimal baseMedicalCompanyPercent; // 基本医疗保险企业比例
    private BigDecimal seriousMedicalCompanyPercent; // 大病医疗保险企业比例
    private Integer billState; // 单据状态
    private String billCode; // 单据编码

    private Integer state; // 状态(0-停用,1-启用)

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getModifyUserName() {
        return modifyUserName;
    }

    public void setModifyUserName(String modifyUserName) {
        this.modifyUserName = modifyUserName;
    }
    public BigDecimal getInsurancePaymentBaseMny() {
        return insurancePaymentBaseMny;
    }

    public void setInsurancePaymentBaseMny(BigDecimal insurancePaymentBaseMny) {
        this.insurancePaymentBaseMny = insurancePaymentBaseMny;
    }
    public BigDecimal getUndertakePercent() {
        return undertakePercent;
    }

    public void setUndertakePercent(BigDecimal undertakePercent) {
        this.undertakePercent = undertakePercent;
    }
    public BigDecimal getEndownmentPersonPercent() {
        return endownmentPersonPercent;
    }

    public void setEndownmentPersonPercent(BigDecimal endownmentPersonPercent) {
        this.endownmentPersonPercent = endownmentPersonPercent;
    }
    public BigDecimal getEndownmentCompanyPercent() {
        return endownmentCompanyPercent;
    }

    public void setEndownmentCompanyPercent(BigDecimal endownmentCompanyPercent) {
        this.endownmentCompanyPercent = endownmentCompanyPercent;
    }
    public BigDecimal getUnemployeePersonPercent() {
        return unemployeePersonPercent;
    }

    public void setUnemployeePersonPercent(BigDecimal unemployeePersonPercent) {
        this.unemployeePersonPercent = unemployeePersonPercent;
    }
    public BigDecimal getUnemployeeCompanyPercent() {
        return unemployeeCompanyPercent;
    }

    public void setUnemployeeCompanyPercent(BigDecimal unemployeeCompanyPercent) {
        this.unemployeeCompanyPercent = unemployeeCompanyPercent;
    }
    public BigDecimal getInjuryPersonPercent() {
        return injuryPersonPercent;
    }

    public void setInjuryPersonPercent(BigDecimal injuryPersonPercent) {
        this.injuryPersonPercent = injuryPersonPercent;
    }
    public BigDecimal getInjuryCompanyPercent() {
        return injuryCompanyPercent;
    }

    public void setInjuryCompanyPercent(BigDecimal injuryCompanyPercent) {
        this.injuryCompanyPercent = injuryCompanyPercent;
    }
    public BigDecimal getBaseMedicalPersonPercent() {
        return baseMedicalPersonPercent;
    }

    public void setBaseMedicalPersonPercent(BigDecimal baseMedicalPersonPercent) {
        this.baseMedicalPersonPercent = baseMedicalPersonPercent;
    }
    public BigDecimal getBaseMedicalCompanyPercent() {
        return baseMedicalCompanyPercent;
    }

    public void setBaseMedicalCompanyPercent(BigDecimal baseMedicalCompanyPercent) {
        this.baseMedicalCompanyPercent = baseMedicalCompanyPercent;
    }
    public BigDecimal getSeriousMedicalCompanyPercent() {
        return seriousMedicalCompanyPercent;
    }

    public void setSeriousMedicalCompanyPercent(BigDecimal seriousMedicalCompanyPercent) {
        this.seriousMedicalCompanyPercent = seriousMedicalCompanyPercent;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    
}

==> ejc-bfyjerp-api-3.0.0-20250718.022422-250-sources.jar: com/ejianc/business/oa/vo/InsurancePaymentSetVO.java <==
package com.ejianc.business.oa.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 人力申请-保险缴纳申请基数设置
 * 
 * @author generator
 * 
 */
public class InsurancePaymentSetVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String createUserName; // 创建人名称
    private String modifyUserName; // 修改人名称
    private BigDecimal insurancePaymentBaseMny; // 保险缴纳基数
    private BigDecimal undertakePercent; // 费用承担比例
    private BigDecimal endownmentPersonPercent; // 养老保险个人比例
    private BigDecimal endownmentCompanyPercent; // 养老保险企业比例
    private BigDecimal unemployeePersonPercent; // 失业保险个人比例
    private BigDecimal unemployeeCompanyPercent; // 失业保险企业比例
    private BigDecimal injuryPersonPercent; // 工伤保险个人比例
    private BigDecimal injuryCompanyPercent; // 工伤保险企业比例
    private BigDecimal baseMedicalPersonPercent; // 基本医疗保险个人比例
    private BigDecimal baseMedicalCompanyPercent; // 基本医疗保险企业比例
    private BigDecimal seriousMedicalCompanyPercent; // 大病医疗保险企业比例
    private Integer billState; // 单据状态
    private String billCode; // 单据编码
    private Long orgId;
    private String orgName;

    private Integer state; // 状态(0-停用,1-启用)

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getModifyUserName() {
        return modifyUserName;
    }

    public void setModifyUserName(String modifyUserName) {
        this.modifyUserName = modifyUserName;
    }
    public BigDecimal getInsurancePaymentBaseMny() {
        return insurancePaymentBaseMny;
    }

    public void setInsurancePaymentBaseMny(BigDecimal insurancePaymentBaseMny) {
        this.insurancePaymentBaseMny = insurancePaymentBaseMny;
    }
    public BigDecimal getUndertakePercent() {
        return undertakePercent;
    }

    public void setUndertakePercent(BigDecimal undertakePercent) {
        this.undertakePercent = undertakePercent;
    }
    public BigDecimal getEndownmentPersonPercent() {
        return endownmentPersonPercent;
    }

    public void setEndownmentPersonPercent(BigDecimal endownmentPersonPercent) {
        this.endownmentPersonPercent = endownmentPersonPercent;
    }
    public BigDecimal getEndownmentCompanyPercent() {
        return endownmentCompanyPercent;
    }

    public void setEndownmentCompanyPercent(BigDecimal endownmentCompanyPercent) {
        this.endownmentCompanyPercent = endownmentCompanyPercent;
    }
    public BigDecimal getUnemployeePersonPercent() {
        return unemployeePersonPercent;
    }

    public void setUnemployeePersonPercent(BigDecimal unemployeePersonPercent) {
        this.unemployeePersonPercent = unemployeePersonPercent;
    }
    public BigDecimal getUnemployeeCompanyPercent() {
        return unemployeeCompanyPercent;
    }

    public void setUnemployeeCompanyPercent(BigDecimal unemployeeCompanyPercent) {
        this.unemployeeCompanyPercent = unemployeeCompanyPercent;
    }
    public BigDecimal getInjuryPersonPercent() {
        return injuryPersonPercent;
    }

    public void setInjuryPersonPercent(BigDecimal injuryPersonPercent) {
        this.injuryPersonPercent = injuryPersonPercent;
    }
    public BigDecimal getInjuryCompanyPercent() {
        return injuryCompanyPercent;
    }

    public void setInjuryCompanyPercent(BigDecimal injuryCompanyPercent) {
        this.injuryCompanyPercent = injuryCompanyPercent;
    }
    public BigDecimal getBaseMedicalPersonPercent() {
        return baseMedicalPersonPercent;
    }

    public void setBaseMedicalPersonPercent(BigDecimal baseMedicalPersonPercent) {
        this.baseMedicalPersonPercent = baseMedicalPersonPercent;
    }
    public BigDecimal getBaseMedicalCompanyPercent() {
        return baseMedicalCompanyPercent;
    }

    public void setBaseMedicalCompanyPercent(BigDecimal baseMedicalCompanyPercent) {
        this.baseMedicalCompanyPercent = baseMedicalCompanyPercent;
    }
    public BigDecimal getSeriousMedicalCompanyPercent() {
        return seriousMedicalCompanyPercent;
    }

    public void setSeriousMedicalCompanyPercent(BigDecimal seriousMedicalCompanyPercent) {
        this.seriousMedicalCompanyPercent = seriousMedicalCompanyPercent;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    
}
